<!--
id: care_vs_justice
title: "Care vs Justice"
category: care
-->

> "Compassion's hand and law's stern gavel,
> tug at moral cords I travel.
> I vow to heed both heart and rule,
> so kindness complements the tool."
